@@ -2,18 +2,17 @@
  * jPlayer Player Plugin for Popcorn JavaScript Library
  * http://www.jplayer.org
  *
- * Copyright (c) 2013 Happyworm Ltd
- * Dual licensed under the MIT and GPL licenses.
- *  - http://www.opensource.org/licenses/mit-license.php
- *  - http://www.gnu.org/copyleft/gpl.html
+ * Copyright (c) 2012 - 2014 Happyworm Ltd
+ * Licensed under the MIT license.
+ * http://opensource.org/licenses/MIT
  *
  * Author: Mark J Panaghiston
- * Version: 1.1.0
- * Date: 20th April 2013
+ * Version: 1.1.4
+ * Date: 1st September 2014
  *
  * For Popcorn Version: 1.3
- * For jPlayer Version: 2.3.0
- * Requires: jQuery 1.3.2+
+ * For jPlayer Version: 2.7.0
+ * Requires: jQuery 1.7+
  * Note: jQuery dependancy cannot be removed since jPlayer 2 is a jQuery plugin. Use of jQuery will be kept to a minimum.
  */
 
@@ -23,16 +22,16 @@
 
 (function(Popcorn) {
 
-	var JQUERY_SCRIPT = 'http://ajax.googleapis.com/ajax/libs/jquery/1.8/jquery.min.js', // Used if jQuery not already present.
-	JPLAYER_SCRIPT = 'http://www.jplayer.org/2.3.0/js/jquery.jplayer.min.js', // Used if jPlayer not already present.
-	JPLAYER_SWFPATH = 'http://www.jplayer.org/2.3.0/js/Jplayer.swf', // Used if not specified in jPlayer options via SRC Object.
+	var JQUERY_SCRIPT = '//code.jquery.com/jquery-1.11.1.min.js', // Used if jQuery not already present.
+	JPLAYER_SCRIPT = '//www.jplayer.org/2.7.0/js/jquery.jplayer.min.js', // Used if jPlayer not already present.
+	JPLAYER_SWFPATH = '//www.jplayer.org/2.7.0/js/Jplayer.swf', // Used if not specified in jPlayer options via SRC Object.
 	SOLUTION = 'html,flash', // The default solution option.
 	DEBUG = false, // Decided to leave the debugging option and console output in for the time being. Overhead is trivial.
 	jQueryDownloading = false, // Flag to stop multiple instances from each pulling in jQuery, thus corrupting it.
 	jPlayerDownloading = false, // Flag to stop multiple instances from each pulling in jPlayer, thus corrupting it.
-	format = { // Duplicate of jPlayer 2.3.0 object, to avoid always requiring jQuery and jPlayer to be loaded before performing the _canPlayType() test.
+	format = { // Duplicate of jPlayer 2.5.0 object, to avoid always requiring jQuery and jPlayer to be loaded before performing the _canPlayType() test.
 		mp3: {
-			codec: 'audio/mpeg; codecs="mp3"',
+			codec: 'audio/mpeg;',
 			flashCanPlay: true,
 			media: 'audio'
 		},
@@ -41,8 +40,23 @@
 			flashCanPlay: true,
 			media: 'audio'
 		},
+		m3u8a: { // AAC / MP4 / Apple HLS
+			codec: 'application/vnd.apple.mpegurl; codecs="mp4a.40.2"',
+			flashCanPlay: false,
+			media: 'audio'
+		},
+		m3ua: { // M3U
+			codec: 'audio/mpegurl',
+			flashCanPlay: false,
+			media: 'audio'
+		},
 		oga: { // OGG
-			codec: 'audio/ogg; codecs="vorbis"',
+			codec: 'audio/ogg; codecs="vorbis, opus"',
+			flashCanPlay: false,
+			media: 'audio'
+		},
+		flac: { // FLAC
+			codec: 'audio/x-flac',
 			flashCanPlay: false,
 			media: 'audio'
 		},
@@ -71,6 +85,16 @@
 			flashCanPlay: true,
 			media: 'video'
 		},
+		m3u8v: { // H.264 / AAC / MP4 / Apple HLS
+			codec: 'application/vnd.apple.mpegurl; codecs="avc1.42E01E, mp4a.40.2"',
+			flashCanPlay: false,
+			media: 'video'
+		},
+		m3uv: { // M3U
+			codec: 'audio/mpegurl',
+			flashCanPlay: false,
+			media: 'video'
+		},
 		ogv: { // OGG
 			codec: 'video/ogg; codecs="theora, vorbis"',
 			flashCanPlay: false,
